/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  21.02.2016  mifi  First Version, tested with an Embedded Artists 
*                    LPC1788 Developer's Kit.
**************************************************************************/
#if !defined(__TALBOARD_H__) && defined(USE_BOARD_EA1788)
#define __TALBOARD_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include "project.h"
#include "taltypes.h"

#include "chip.h"

/**************************************************************************
*  Global Definitions
**************************************************************************/

/*
 * Defines for board and cpu name
 */
#define TAL_BOARD "EA1788"
#define TAL_CPU   "LPC1788"


/*
 * Check OSCILLATOR_CLOCK_FREQUENCY value, must be 12MHz
 */
#if (OSCILLATOR_CLOCK_FREQUENCY != 12000000)
   Error: OSCILLATOR_CLOCK_FREQUENCY must defined to 12000000 by the preprocessor;
#endif   


/*
 * With 5 bits of interrupt priority 32 levels are
 * available. Priority 0 is the highest one, 31 the lowest.
 */

#ifndef SYSTICK_PRIO
#define SYSTICK_PRIO       0
#endif 

#ifndef UART0_PRIO
#define UART0_PRIO         7
#endif

#ifndef UART2_PRIO
#define UART2_PRIO         7
#endif

#ifndef CAN_PRIO
#define CAN_PRIO           6
#endif


/*
 * The Embedded Artists LPC1788 Developer's Kit support 2 LEDs
 */
typedef enum _tal_led_channel_
{
   TAL_LED_CHANNEL_1 = 0,
   TAL_LED_CHANNEL_2,
   
   TAL_LED_CHANNEL_3,
   TAL_LED_CHANNEL_4,
   TAL_LED_CHANNEL_5,
   TAL_LED_CHANNEL_6,
   TAL_LED_CHANNEL_7,
   TAL_LED_CHANNEL_8,
   TAL_LED_CHANNEL_9,
   TAL_LED_CHANNEL_10,
   TAL_LED_CHANNEL_11,
   TAL_LED_CHANNEL_12,
   TAL_LED_CHANNEL_13,
   TAL_LED_CHANNEL_14,
   TAL_LED_CHANNEL_15,
   TAL_LED_CHANNEL_16,
   TAL_LED_CHANNEL_17,
   TAL_LED_CHANNEL_18,
   
   /* TAL_LED_CHANNEL_MAX must be the last one */
   TAL_LED_CHANNEL_MAX
} TAL_LED_CHANNEL;

/*
 * LED name from the board itself
 */
#define LED3   TAL_LED_CHANNEL_1
#define LED4   TAL_LED_CHANNEL_2

/*
 * COM port used for the terminal
 */
#if !defined(TERM_COM_PORT)
#define TERM_COM_PORT   TAL_COM_PORT_3
#endif

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

void       tal_BoardMemInit (void);

TAL_RESULT tal_BoardEnableCOM1(void);
TAL_RESULT tal_BoardEnableCOM2(void);
TAL_RESULT tal_BoardEnableCOM3(void);
TAL_RESULT tal_BoardEnableCOM4(void);
TAL_RESULT tal_BoardEnableCOM5(void);

TAL_RESULT tal_BoardEnableCAN1(void);
TAL_RESULT tal_BoardEnableCAN2(void);

#endif /* !__TALBOARD_H__ */

/*** EOF ***/
